# Ｖ　Ａ　Ｐ　Ｅ

A command-line aesthetic text generator. Perfect for your new Vaporwave band.

Might also be useful for getting around text filters, who knows.

## Ｉｎｓｔａｌｌａｔｉｏｎ 

    $ pip install vape

## Ｕｓａｇｅ 

    $ vape I want to be AESTHETIC
    Ｉ　ｗａｎｔ　ｔｏ　ｂｅ　ＡＥＳＴＨＥＴＩＣ

You can copy the result to the clipboard with `-c`.

You can also force upper case text with `-u`. 

And that's all it does!

## See Also
* [Emo](https://github.com/Miserlou/Emo)
* [Zalgo](https://github.com/Miserlou/Zalgo)

Ｒｉｃｈ　Ｊｏｎｅｓ　２０１７
